diff --git a/doc/languages-frameworks/go.section.md b/doc/languages-frameworks/go.section.md
index 9c67a514335e..8616d64e7c4e 100644
--- a/doc/languages-frameworks/go.section.md
+++ b/doc/languages-frameworks/go.section.md
@@ -11,8 +11,8 @@ The function `buildGoModule` builds Go programs managed with Go modules. It buil
In the following is an example expression using `buildGoModule`, the following arguments are of special significance to the function:
-- `vendorSha256`: is the hash of the output of the intermediate fetcher derivation. `vendorSha256` can also take `null` as an input. When `null` is used as a value, rather than fetching the dependencies and vendoring them, we use the vendoring included within the source repo. If you'd like to not have to update this field on dependency changes, run `go mod vendor` in your source repo and set `vendorSha256 = null;`
-- `proxyVendor`: Fetches (go mod download) and proxies the vendor directory. This is useful if your code depends on c code and go mod tidy does not include the needed sources to build or if any dependency has case-insensitive conflicts which will produce platform dependant `vendorSha256` checksums.
+- `vendorHash`: is the hash of the output of the intermediate fetcher derivation. `vendorHash` can also take `null` as an input. When `null` is used as a value, rather than fetching the dependencies and vendoring them, we use the vendoring included within the source repo. If you'd like to not have to update this field on dependency changes, run `go mod vendor` in your source repo and set `vendorHash = null;`
+- `proxyVendor`: Fetches (go mod download) and proxies the vendor directory. This is useful if your code depends on c code and go mod tidy does not include the needed sources to build or if any dependency has case-insensitive conflicts which will produce platform dependant `vendorHash` checksums.
```nix
pet = buildGoModule rec {
@@ -26,7 +26,7 @@ pet = buildGoModule rec {
sha256 = "0m2fzpqxk7hrbxsgqplkg7h2p7gv6s1miymv3gvw0cz039skag0s";
};
- vendorSha256 = "1879j77k96684wi554rkjxydrj8g3hpp0kvxz03sd8dmwr3lh83j";
+ vendorHash = "sha256-ciBIR+a1oaYH+H1PcC8cD8ncfJczk1IiJ8iYNM+R6aA=";
meta = with lib; {
description = "Simple command-line snippet manager, written in Go";
diff --git a/nixos/doc/manual/from_md/release-notes/rl-2211.section.xml b/nixos/doc/manual/from_md/release-notes/rl-2211.section.xml
index 19949b932f15..882eea3c4a4a 100644
--- a/nixos/doc/manual/from_md/release-notes/rl-2211.section.xml
+++ b/nixos/doc/manual/from_md/release-notes/rl-2211.section.xml
@@ -271,6 +271,14 @@
maintainer to update the package.
+
+
+ xow package removed along with the
+ hardware.xow module, due to the project
+ being deprecated in favor of xone, which is
+ available via the hardware.xone module.
+
+
The services.graphite.api and
diff --git a/nixos/doc/manual/release-notes/rl-2211.section.md b/nixos/doc/manual/release-notes/rl-2211.section.md
index 4d9da9f09969..a2757d67e89c 100644
--- a/nixos/doc/manual/release-notes/rl-2211.section.md
+++ b/nixos/doc/manual/release-notes/rl-2211.section.md
@@ -105,6 +105,8 @@ In addition to numerous new and upgraded packages, this release has the followin
- riak package removed along with `services.riak` module, due to lack of maintainer to update the package.
+- xow package removed along with the `hardware.xow` module, due to the project being deprecated in favor of `xone`, which is available via the `hardware.xone` module.
+
- The `services.graphite.api` and `services.graphite.beacon` NixOS options, and
the `python3.pkgs.graphite_api`, `python3.pkgs.graphite_beacon` and
`python3.pkgs.influxgraph` packages, have been removed due to lack of upstream
diff --git a/nixos/modules/module-list.nix b/nixos/modules/module-list.nix
index d961e2f683bd..616f357663ca 100644
--- a/nixos/modules/module-list.nix
+++ b/nixos/modules/module-list.nix
@@ -475,7 +475,6 @@
./services/hardware/thermald.nix
./services/hardware/undervolt.nix
./services/hardware/vdr.nix
- ./services/hardware/xow.nix
./services/home-automation/home-assistant.nix
./services/home-automation/zigbee2mqtt.nix
./services/logging/SystemdJournal2Gelf.nix
diff --git a/nixos/modules/rename.nix b/nixos/modules/rename.nix
index 22fcb72e9ff4..f86aa2fa5c1b 100644
--- a/nixos/modules/rename.nix
+++ b/nixos/modules/rename.nix
@@ -30,6 +30,10 @@ with lib;
udev rules from libu2f-host to the system. Udev gained native support
to handle FIDO security tokens, so this isn't necessary anymore.
'')
+ (mkRemovedOptionModule [ "hardware" "xow" ] ''
+ The xow package was removed from nixpkgs. Upstream has deprecated
+ the project and users are urged to switch to xone.
+ '')
(mkRemovedOptionModule [ "networking" "vpnc" ] "Use environment.etc.\"vpnc/service.conf\" instead.")
(mkRemovedOptionModule [ "networking" "wicd" ] "The corresponding package was removed from nixpkgs.")
(mkRemovedOptionModule [ "programs" "tilp2" ] "The corresponding package was removed from nixpkgs.")
diff --git a/nixos/modules/services/hardware/xow.nix b/nixos/modules/services/hardware/xow.nix
deleted file mode 100644
index 311181176bd8..000000000000
--- a/nixos/modules/services/hardware/xow.nix
+++ /dev/null
@@ -1,20 +0,0 @@
-{ config, pkgs, lib, ... }:
-
-let
- cfg = config.services.hardware.xow;
-in {
- options.services.hardware.xow = {
- enable = lib.mkEnableOption "xow as a systemd service";
- };
-
- config = lib.mkIf cfg.enable {
- hardware.uinput.enable = true;
-
- boot.extraModprobeConfig = lib.readFile "${pkgs.xow}/lib/modprobe.d/xow-blacklist.conf";
-
- systemd.packages = [ pkgs.xow ];
- systemd.services.xow.wantedBy = [ "multi-user.target" ];
-
- services.udev.packages = [ pkgs.xow ];
- };
-}
diff --git a/nixos/modules/services/misc/klipper.nix b/nixos/modules/services/misc/klipper.nix
index 7b3780b5cc9f..fee7779141cd 100644
--- a/nixos/modules/services/misc/klipper.nix
+++ b/nixos/modules/services/misc/klipper.nix
@@ -5,9 +5,9 @@ let
format = pkgs.formats.ini {
# https://github.com/NixOS/nixpkgs/pull/121613#issuecomment-885241996
listToValue = l:
- if builtins.length l == 1 then generators.mkValueStringDefault {} (head l)
+ if builtins.length l == 1 then generators.mkValueStringDefault { } (head l)
else lib.concatMapStrings (s: "\n ${generators.mkValueStringDefault {} s}") l;
- mkKeyValue = generators.mkKeyValueDefault {} ":";
+ mkKeyValue = generators.mkKeyValueDefault { } ":";
};
in
{
@@ -69,6 +69,24 @@ in
for supported values.
'';
};
+
+ firmwares = mkOption {
+ description = "Firmwares klipper should manage";
+ default = { };
+ type = with types; attrsOf
+ (submodule {
+ options = {
+ enable = mkEnableOption ''
+ building of firmware and addition of klipper-flash tools for manual flashing.
+ This will add `klipper-flash-$mcu` scripts to your environment which can be called to flash the firmware.
+ '';
+ configFile = mkOption {
+ type = path;
+ description = "Path to firmware config which is generated using `klipper-genconf`";
+ };
+ };
+ });
+ };
};
};
@@ -83,6 +101,10 @@ in
assertion = cfg.user != null -> cfg.group != null;
message = "Option klipper.group is not set when a user is specified.";
}
+ {
+ assertion = foldl (a: b: a && b) true (mapAttrsToList (mcu: _: mcu != null -> (hasAttrByPath [ "${mcu}" "serial" ] cfg.settings)) cfg.firmwares);
+ message = "Option klipper.settings.$mcu.serial must be set when klipper.firmware.$mcu is specified";
+ }
];
environment.etc."klipper.cfg".source = format.generate "klipper.cfg" cfg.settings;
@@ -92,26 +114,48 @@ in
group = config.services.octoprint.group;
};
- systemd.services.klipper = let
- klippyArgs = "--input-tty=${cfg.inputTTY}"
- + optionalString (cfg.apiSocket != null) " --api-server=${cfg.apiSocket}";
- in {
- description = "Klipper 3D Printer Firmware";
- wantedBy = [ "multi-user.target" ];
- after = [ "network.target" ];
+ systemd.services.klipper =
+ let
+ klippyArgs = "--input-tty=${cfg.inputTTY}"
+ + optionalString (cfg.apiSocket != null) " --api-server=${cfg.apiSocket}";
+ in
+ {
+ description = "Klipper 3D Printer Firmware";
+ wantedBy = [ "multi-user.target" ];
+ after = [ "network.target" ];
- serviceConfig = {
- ExecStart = "${cfg.package}/lib/klipper/klippy.py ${klippyArgs} /etc/klipper.cfg";
- RuntimeDirectory = "klipper";
- SupplementaryGroups = [ "dialout" ];
- WorkingDirectory = "${cfg.package}/lib";
- } // (if cfg.user != null then {
- Group = cfg.group;
- User = cfg.user;
- } else {
- DynamicUser = true;
- User = "klipper";
- });
- };
+ serviceConfig = {
+ ExecStart = "${cfg.package}/lib/klipper/klippy.py ${klippyArgs} /etc/klipper.cfg";
+ RuntimeDirectory = "klipper";
+ SupplementaryGroups = [ "dialout" ];
+ WorkingDirectory = "${cfg.package}/lib";
+ } // (if cfg.user != null then {
+ Group = cfg.group;
+ User = cfg.user;
+ } else {
+ DynamicUser = true;
+ User = "klipper";
+ });
+ };
+
+ environment.systemPackages =
+ with pkgs;
+ let
+ firmwares = filterAttrs (n: v: v!= null) (mapAttrs
+ (mcu: { enable, configFile }: if enable then pkgs.klipper-firmware.override {
+ mcu = lib.strings.sanitizeDerivationName mcu;
+ firmwareConfig = configFile;
+ } else null)
+ cfg.firmwares);
+ firmwareFlasher = mapAttrsToList
+ (mcu: firmware: pkgs.klipper-flash.override {
+ mcu = lib.strings.sanitizeDerivationName mcu;
+ klipper-firmware = firmware;
+ flashDevice = cfg.settings."${mcu}".serial;
+ firmwareConfig = cfg.firmwares."${mcu}".configFile;
+ })
+ firmwares;
+ in
+ [ klipper-genconf ] ++ firmwareFlasher ++ attrValues firmwares;
};
}
diff --git a/pkgs/applications/audio/jellycli/default.nix b/pkgs/applications/audio/jellycli/default.nix
index ec60998ec8ff..3654eacfbd6c 100644
--- a/pkgs/applications/audio/jellycli/default.nix
+++ b/pkgs/applications/audio/jellycli/default.nix
@@ -11,7 +11,7 @@ buildGoModule rec {
sha256 = "1awzcxnf175a794rhzbmqxxjss77mfa1yrr0wgdxaivrlkibxjys";
};
- vendorSha256 = "02fwsnrhj09m0aa199plpqlsjrwpmrk4c80fszzm07s5vmjqvnfy";
+ vendorHash = "sha256-3tmNZd1FH1D/1w4gRmaul2epKb70phSUAjUBCbPV3Ak=";
patches = [
# Fixes log file path for tests.
diff --git a/pkgs/applications/audio/noisetorch/default.nix b/pkgs/applications/audio/noisetorch/default.nix
index 9fcd35a9de32..f422ad7fe136 100644
--- a/pkgs/applications/audio/noisetorch/default.nix
+++ b/pkgs/applications/audio/noisetorch/default.nix
@@ -12,7 +12,7 @@ buildGoModule rec {
fetchSubmodules = true;
};
- vendorSha256 = null;
+ vendorHash = null;
doCheck = false;
diff --git a/pkgs/applications/blockchains/exodus/default.nix b/pkgs/applications/blockchains/exodus/default.nix
index 064b8a2d489e..00fe747193a5 100644
--- a/pkgs/applications/blockchains/exodus/default.nix
+++ b/pkgs/applications/blockchains/exodus/default.nix
@@ -1,4 +1,4 @@
-{ stdenv, lib, fetchurl, unzip, glib, systemd, nss, nspr, gtk3-x11, pango,
+{ stdenv, lib, fetchzip, glib, systemd, nss, nspr, gtk3-x11, pango,
atk, cairo, gdk-pixbuf, xorg, xorg_sys_opengl, util-linux, alsa-lib, dbus, at-spi2-atk,
cups, vivaldi-ffmpeg-codecs, libpulseaudio, at-spi2-core, libxkbcommon, mesa }:
@@ -6,19 +6,13 @@ stdenv.mkDerivation rec {
pname = "exodus";
version = "22.7.15";
- src = fetchurl {
+ src = fetchzip {
url = "https://downloads.exodus.io/releases/${pname}-linux-x64-${version}.zip";
- sha256 = "sha256-tQwxzhy+d2hA7VvZB9qSF7uaYIffAyX9ovZYQ8HDEB8=";
+ sha256 = "sha256-KAv+H6uJBDGzjg5Qmy54EtiVvV1OGJ6r3XnAQO7qjIg=";
};
- sourceRoot = ".";
- unpackCmd = ''
- ${unzip}/bin/unzip "$src" -x "Exodus*/lib*so"
- '';
-
installPhase = ''
mkdir -p $out/bin $out/share/applications
- cd Exodus-linux-x64
cp -r . $out
ln -s $out/Exodus $out/bin/Exodus
ln -s $out/bin/Exodus $out/bin/exodus
diff --git a/pkgs/applications/graphics/ImageMagick/default.nix b/pkgs/applications/graphics/ImageMagick/default.nix
index 3b58aba1e556..f1a9d7ae6724 100644
--- a/pkgs/applications/graphics/ImageMagick/default.nix
+++ b/pkgs/applications/graphics/ImageMagick/default.nix
@@ -46,13 +46,13 @@ in
stdenv.mkDerivation rec {
pname = "imagemagick";
- version = "7.1.0-43";
+ version = "7.1.0-44";
src = fetchFromGitHub {
owner = "ImageMagick";
repo = "ImageMagick";
- rev = builtins.replaceStrings [ "-" ] [ "." ] version;
- hash = "sha256-SOy7Ci1rzLB12ofSQBWmX86dfbr/ywsRPunHRswlAt4=";
+ rev = version;
+ hash = "sha256-vJGZ47l8nSRnINWHsw562zsQ14fSR5SObr/SO+/40yw=";
};
outputs = [ "out" "dev" "doc" ]; # bin/ isn't really big
diff --git a/pkgs/applications/misc/fbreader/default.nix b/pkgs/applications/misc/fbreader/default.nix
deleted file mode 100644
index c684d273bc75..000000000000
--- a/pkgs/applications/misc/fbreader/default.nix
+++ /dev/null
@@ -1,94 +0,0 @@
-{ lib
-, stdenv
-, fetchFromGitHub
-, fetchpatch
-, pkg-config
-, bzip2
-, curl
-, expat
-, fribidi
-, libunibreak
-, sqlite
-, zlib
-, uiTarget ? if !stdenv.isDarwin then "desktop" else "macosx"
-, uiType ? if !stdenv.isDarwin then "qt4" else "cocoa"
-, qt4
-, gtk2
-, AppKit
-, Cocoa
-}:
-
-with lib;
-
-assert elem uiTarget [ "desktop" "macosx" ];
-assert elem uiType [ "qt4" "gtk" "cocoa" ];
-assert uiTarget == "macosx" -> uiType == "cocoa";
-
-# Note: "qt" uiType option mentioned in ${src}/README.build is qt3,
-# which is way to old and no longer in nixpkgs.
-
-stdenv.mkDerivation {
- pname = "fbreader-${uiType}";
- version = "0.99.6";
-
- src = fetchFromGitHub {
- owner = "geometer";
- repo = "FBReader";
- rev = "9e608db14372ae580beae4976eec7241fa069e75";
- sha256 = "0lzafk02mv0cf2l2a61q5y4743zi913byik4bw1ix0gr1drnsa7y";
- };
-
- patches = [
- ./typecheck.patch
- (fetchpatch {
- name = "curl-7_62.diff"; # see https://github.com/geometer/FBReader/pull/311
- url = "https://github.com/geometer/FBReader/commit/b7c78e965d06f780.diff";
- sha256 = "1dgnx9wps7hcf8fkidc7037vcf92fr3ccnjx7bgxm9x02j0hngjg";
- })
- ];
-
- postPatch = ''
- cat << EOF > makefiles/target.mk
- TARGET_ARCH = ${uiTarget}
- TARGET_STATUS = release
- UI_TYPE = ${uiType}
- EOF
-
- substituteInPlace makefiles/arch/desktop.mk \
- --replace ccache "" \
- --replace moc-qt4 moc
-
- # libunibreak supersedes liblinebreak
- substituteInPlace zlibrary/text/Makefile \
- --replace -llinebreak -lunibreak
- '';
-
- nativeBuildInputs = [ pkg-config ];
-
- buildInputs = [
- bzip2
- curl
- expat
- fribidi
- libunibreak
- sqlite
- zlib
- ]
- ++ optional (uiType == "qt4") qt4
- ++ optional (uiType == "gtk") gtk2
- ++ optionals (uiType == "cocoa") [ AppKit Cocoa ];
-
- makeFlags = [ "INSTALLDIR=$(out)" ];
-
- NIX_CFLAGS_COMPILE = "-Wno-error=narrowing";
-
- meta = with lib; {
- description = "An e-book reader for Linux";
- homepage = "http://www.fbreader.org/";
- license = licenses.gpl3;
- broken = stdenv.isDarwin # untested, might work
- || uiType == "gtk"; # builds, but the result is unusable, hangs a lot
- platforms = platforms.unix;
- maintainers = [ maintainers.coroa ];
- };
-}
diff --git a/pkgs/applications/misc/fbreader/typecheck.patch b/pkgs/applications/misc/fbreader/typecheck.patch
deleted file mode 100644
index cbac290e69c2..000000000000
--- a/pkgs/applications/misc/fbreader/typecheck.patch
+++ /dev/null
@@ -1,11 +0,0 @@
-diff --git a/fbreader/src/database/booksdb/BooksDB.cpp b/fbreader/src/database/booksdb/BooksDB.cpp
-index e33a22e76..1b6092800 100644
---- a/fbreader/src/database/booksdb/BooksDB.cpp
-+++ b/fbreader/src/database/booksdb/BooksDB.cpp
-@@ -146,5 +146,5 @@ shared_ptr BooksDB::loadBook(const std::string &fileName) {
- myFindFileId->setFileName(fileName);
- if (!myFindFileId->run()) {
-- return false;
-+ return 0;
- }
- ((DBIntValue&)*myLoadBook->parameter("@file_id").value()) = myFindFileId->fileId();
diff --git a/pkgs/applications/science/robotics/qgroundcontrol/default.nix b/pkgs/applications/science/robotics/qgroundcontrol/default.nix
index 92f6ebe6ceb9..8ed3cd8749fa 100644
--- a/pkgs/applications/science/robotics/qgroundcontrol/default.nix
+++ b/pkgs/applications/science/robotics/qgroundcontrol/default.nix
@@ -6,7 +6,7 @@
mkDerivation rec {
pname = "qgroundcontrol";
- version = "4.2.1";
+ version = "4.2.3";
qtInputs = [
qtbase qtcharts qtlocation qtserialport qtsvg qtquickcontrols2
@@ -14,7 +14,12 @@ mkDerivation rec {
];
gstInputs = with gst_all_1; [
- gstreamer gst-plugins-base gst-plugins-good gst-plugins-bad wayland
+ gstreamer
+ gst-plugins-base
+ (gst-plugins-good.override { qt5Support = true; })
+ gst-plugins-bad
+ gst-libav
+ wayland
];
buildInputs = [ SDL2 ] ++ gstInputs ++ qtInputs;
@@ -64,7 +69,7 @@ mkDerivation rec {
owner = "mavlink";
repo = pname;
rev = "v${version}";
- sha256 = "sha256-7POrc6RUm3GVx3KuPUBNbKRUvUmA2UkEL7ezQVQt/yo=";
+ sha256 = "sha256-xa4c0ggQKqt4OfwVehjkhXYXY1TYVEoubuRH3Zsv0Ac=";
fetchSubmodules = true;
};
diff --git a/pkgs/applications/terminal-emulators/gnome-console/default.nix b/pkgs/applications/terminal-emulators/gnome-console/default.nix
index 691a2d10c67c..790aa1725923 100644
--- a/pkgs/applications/terminal-emulators/gnome-console/default.nix
+++ b/pkgs/applications/terminal-emulators/gnome-console/default.nix
@@ -1,6 +1,7 @@
{ lib
, stdenv
, fetchurl
+, fetchpatch
, gettext
, gnome
, libgtop
@@ -29,14 +30,23 @@ stdenv.mkDerivation rec {
sha256 = "fSbmwYdExXWnhykyY/YM7/YwEHCY6eWKd2WwCsdDcEk=";
};
+ patches = [
+ (fetchpatch {
+ name = "fix-clang-build-issues.patch";
+ url = "https://gitlab.gnome.org/GNOME/console/-/commit/0e29a417d52e27da62f5cac461400be6a764dc65.patch";
+ sha256 = "sha256-5ORNZOxjC5dMk9VKaBcJu5OV1SEZo9SNUbN4Ob5hVJs=";
+ })
+ ];
+
buildInputs = [
gettext
libgtop
- gnome.nautilus
gtk3
libhandy
pcre2
vte
+ ] ++ lib.optionals stdenv.isLinux [
+ gnome.nautilus
];
nativeBuildInputs = [
@@ -51,6 +61,10 @@ stdenv.mkDerivation rec {
wrapGAppsHook
];
+ mesonFlags = lib.optionals (!stdenv.isLinux) [
+ "-Dnautilus=disabled"
+ ];
+
passthru = {
updateScript = gnome.updateScript {
packageName = pname;
@@ -64,6 +78,6 @@ stdenv.mkDerivation rec {
homepage = "https://gitlab.gnome.org/GNOME/console";
license = licenses.gpl3Plus;
maintainers = teams.gnome.members ++ (with maintainers; [ zhaofengli ]);
- platforms = platforms.linux;
+ platforms = platforms.unix;
};
}
diff --git a/pkgs/applications/video/freetube/default.nix b/pkgs/applications/video/freetube/default.nix
index c93be6b63834..3ceda283d3d8 100644
--- a/pkgs/applications/video/freetube/default.nix
+++ b/pkgs/applications/video/freetube/default.nix
@@ -2,11 +2,11 @@
stdenv.mkDerivation rec {
pname = "freetube";
- version = "0.16.0";
+ version = "0.17.0";
src = fetchurl {
url = "https://github.com/FreeTubeApp/FreeTube/releases/download/v${version}-beta/freetube_${version}_amd64.AppImage";
- sha256 = "sha256-G4lZ1lbNN8X9ocWhcuuNZGTZm9AUzuWKVm23YgsJwig=";
+ sha256 = "sha256-OlWNln62VouUJzzk0CtED+OdSM+aBc4NOu1TSaKVWnk=";
};
appimageContents = appimageTools.extractType2 {
diff --git a/pkgs/applications/window-managers/weston/default.nix b/pkgs/applications/window-managers/weston/default.nix
index 10f67558cfcb..799c58283d93 100644
--- a/pkgs/applications/window-managers/weston/default.nix
+++ b/pkgs/applications/window-managers/weston/default.nix
@@ -7,7 +7,6 @@
# beware of null defaults, as the parameters *are* supplied by callPackage by default
}:
-with lib;
stdenv.mkDerivation rec {
pname = "weston";
version = "10.0.1";
@@ -34,25 +33,25 @@ stdenv.mkDerivation rec {
];
mesonFlags= [
- "-Dbackend-drm-screencast-vaapi=${boolToString (vaapi != null)}"
- "-Dbackend-rdp=${boolToString (freerdp != null)}"
- "-Dxwayland=${boolToString (xwayland != null)}" # Default is true!
+ "-Dbackend-drm-screencast-vaapi=${lib.boolToString (vaapi != null)}"
+ "-Dbackend-rdp=${lib.boolToString (freerdp != null)}"
+ "-Dxwayland=${lib.boolToString (xwayland != null)}" # Default is true!
"-Dremoting=false" # TODO
- "-Dpipewire=${boolToString (pipewire != null)}"
- "-Dimage-webp=${boolToString (libwebp != null)}"
+ "-Dpipewire=${lib.boolToString (pipewire != null)}"
+ "-Dimage-webp=${lib.boolToString (libwebp != null)}"
"-Ddemo-clients=false"
"-Dsimple-clients="
"-Dtest-junit-xml=false"
# TODO:
#"--enable-clients"
#"--disable-setuid-install" # prevent install target to chown root weston-launch, which fails
- ] ++ optionals (xwayland != null) [
+ ] ++ lib.optionals (xwayland != null) [
"-Dxwayland-path=${xwayland.out}/bin/Xwayland"
];
passthru.providedSessions = [ "weston" ];
- meta = {
+ meta = with lib; {
description = "A lightweight and functional Wayland compositor";
longDescription = ''
Weston is the reference implementation of a Wayland compositor, as well
diff --git a/pkgs/development/compilers/crystal/default.nix b/pkgs/development/compilers/crystal/default.nix
index 9cf3bebe7ed9..88274ef73c94 100644
--- a/pkgs/development/compilers/crystal/default.nix
+++ b/pkgs/development/compilers/crystal/default.nix
@@ -2,6 +2,7 @@
, callPackage
, fetchFromGitHub
, fetchurl
+, fetchpatch
, lib
# Dependencies
, boehmgc
@@ -97,6 +98,16 @@ let
inherit sha256;
};
+ patches = lib.optionals (lib.versionOlder version "1.2.0") [
+ # add support for DWARF5 debuginfo, fixes builds on recent compilers
+ # the PR is 8 commits from 2019, so just fetch the whole thing
+ # and hope it doesn't change
+ (fetchpatch {
+ url = "https://github.com/crystal-lang/crystal/pull/11399.patch";
+ sha256 = "sha256-CjNpkQQ2UREADmlyLUt7zbhjXf0rTjFhNbFYLwJKkc8=";
+ })
+ ];
+
outputs = [ "out" "lib" "bin" ];
postPatch = ''
diff --git a/pkgs/development/compilers/go/1.17.nix b/pkgs/development/compilers/go/1.17.nix
index db2133d0110e..e2db700494e9 100644
--- a/pkgs/development/compilers/go/1.17.nix
+++ b/pkgs/development/compilers/go/1.17.nix
@@ -60,11 +60,11 @@ in
stdenv.mkDerivation rec {
pname = "go";
- version = "1.17.12";
+ version = "1.17.13";
src = fetchurl {
url = "https://dl.google.com/go/go${version}.src.tar.gz";
- sha256 = "sha256-DVG1s/KAwPAfU0WYwCGdtYePM32mE3qe5ph3dBNgcgk=";
+ sha256 = "sha256-oaSLI6+yBvlee7qpuJjZZfkIJvbx0fwMHXhK2gzTAP0=";
};
strictDeps = true;
diff --git a/pkgs/development/interpreters/nickel/default.nix b/pkgs/development/interpreters/nickel/default.nix
index 7a097391ba5d..ccf34377de42 100644
--- a/pkgs/development/interpreters/nickel/default.nix
+++ b/pkgs/development/interpreters/nickel/default.nix
@@ -5,16 +5,16 @@
rustPlatform.buildRustPackage rec {
pname = "nickel";
- version = "0.1.0";
+ version = "0.2.0";
src = fetchFromGitHub {
owner = "tweag";
repo = pname;
rev = "refs/tags/${version}"; # because pure ${version} doesn't work
- hash = "sha256-St8oK9vP2cAhsNindkebtAMeRPwYggP9E4CciSZc7oA=";
+ hash = "sha256-Bh83qn+ECZnlCH/A34G5G5MdcAHPow24RMCVQXR5Awg=";
};
- cargoSha256 = "sha256-VsyK/api8acIpADpXQ8RdbRLiZwHFSDH0vwQrZQ8zp4=";
+ cargoSha256 = "sha256-vI+SaVyRJjLNqenUsYtaSTyOZRT0zZJ1OZHekcb5LjY=";
meta = with lib; {
homepage = "https://nickel-lang.org/";
diff --git a/pkgs/development/libraries/argparse/default.nix b/pkgs/development/libraries/argparse/default.nix
new file mode 100644
index 000000000000..ac195e909c67
--- /dev/null
+++ b/pkgs/development/libraries/argparse/default.nix
@@ -0,0 +1,25 @@
+{ lib, stdenv, fetchFromGitHub, cmake }:
+
+stdenv.mkDerivation rec {
+ pname = "argparse";
+ version = "2.6";
+
+ src = fetchFromGitHub {
+ owner = "p-ranav";
+ repo = "argparse";
+ rev = "v${version}";
+ sha256 = "sha256-imLDuVbzkiE5hcQVarZGeNzNZE0/8LHMQqAiUYzPVks=";
+ };
+
+ nativeBuildInputs = [
+ cmake
+ ];
+
+ meta = with lib; {
+ description = "Argument Parser for Modern C++";
+ homepage = "https://github.com/p-ranav/argparse";
+ maintainers = with maintainers; [ _2gn ];
+ platforms = platforms.unix;
+ license = licenses.mit;
+ };
+}
diff --git a/pkgs/development/libraries/live555/default.nix b/pkgs/development/libraries/live555/default.nix
index f212adb03beb..6b5f6410d54f 100644
--- a/pkgs/development/libraries/live555/default.nix
+++ b/pkgs/development/libraries/live555/default.nix
@@ -10,7 +10,7 @@
stdenv.mkDerivation rec {
pname = "live555";
- version = "2022.06.16";
+ version = "2022.07.14";
src = fetchurl {
urls = [
@@ -18,7 +18,7 @@ stdenv.mkDerivation rec {
"https://download.videolan.org/contrib/live555/live.${version}.tar.gz"
"mirror://sourceforge/slackbuildsdirectlinks/live.${version}.tar.gz"
];
- sha256 = "sha256-84OUQw++RNqH3sAY4S6yXRJXZY+5T0VdTIUqELuVdV0=";
+ sha256 = "sha256-VrWkBmLdP0MYfiFit3Mtkv7Ti8dWPmrndrbKo+BpRCA=";
};
nativeBuildInputs = lib.optional stdenv.isDarwin darwin.cctools;
diff --git a/pkgs/development/libraries/vte/default.nix b/pkgs/development/libraries/vte/default.nix
index 8734308af930..342bb32e5609 100644
--- a/pkgs/development/libraries/vte/default.nix
+++ b/pkgs/development/libraries/vte/default.nix
@@ -78,6 +78,9 @@ stdenv.mkDerivation rec {
mesonFlags = lib.optionals (!systemdSupport) [
"-D_systemd=false"
+ ] ++ lib.optionals stdenv.isDarwin [
+ # -Bsymbolic-functions is not supported on darwin
+ "-D_b_symbolic_functions=false"
];
postPatch = ''
@@ -98,7 +101,6 @@ stdenv.mkDerivation rec {
};
meta = with lib; {
- broken = stdenv.isDarwin;
homepage = "https://www.gnome.org/";
description = "A library implementing a terminal emulator widget for GTK";
longDescription = ''
diff --git a/pkgs/development/python-modules/adafruit-nrfutil/default.nix b/pkgs/development/python-modules/adafruit-nrfutil/default.nix
new file mode 100644
index 000000000000..532fd301a1a4
--- /dev/null
+++ b/pkgs/development/python-modules/adafruit-nrfutil/default.nix
@@ -0,0 +1,62 @@
+{ lib
+, buildPythonPackage
+, fetchFromGitHub
+, fetchpatch
+, pythonOlder
+, pyserial
+, click
+, ecdsa
+, behave
+, nose
+}:
+
+buildPythonPackage rec {
+ pname = "adafruit-nrfutil";
+ version = "0.5.3.post17";
+ format = "setuptools";
+
+ disabled = pythonOlder "3.7";
+
+ src = fetchFromGitHub {
+ owner = "adafruit";
+ repo = "Adafruit_nRF52_nrfutil";
+ rev = version;
+ sha256 = "sha256-mHHKOQE9AGBX8RAyaPOy+JS3fTs98+AFdq9qsVy7go4=";
+ };
+
+ patches = [
+ # Pull a patch which fixes the tests, but is not yet released in a new version:
+ # https://github.com/adafruit/Adafruit_nRF52_nrfutil/pull/38
+ (fetchpatch {
+ name = "fix-tests.patch";
+ url = "https://github.com/adafruit/Adafruit_nRF52_nrfutil/commit/e5fbcc8ee5958041db38c04139ba686bf7d1b845.patch";
+ sha256 = "sha256-0tbJldGtYcDdUzA3wZRv0lenXVn6dqV016U9nMpQ6/w=";
+ })
+ ];
+
+ propagatedBuildInputs = [
+ pyserial
+ click
+ ecdsa
+ ];
+
+ checkInputs = [
+ behave
+ nose
+ ];
+
+ preCheck = ''
+ mkdir test-reports
+ '';
+
+ pythonImportsCheck = [
+ "nordicsemi"
+ ];
+
+ meta = with lib; {
+ homepage = "https://github.com/adafruit/Adafruit_nRF52_nrfutil";
+ description = "Modified version of Nordic's nrfutil 0.5.x for use with the Adafruit Feather nRF52";
+ license = licenses.bsd3;
+ maintainers = with maintainers; [ stargate01 ];
+ };
+}
diff --git a/pkgs/development/python-modules/aioaladdinconnect/default.nix b/pkgs/development/python-modules/aioaladdinconnect/default.nix
index 52680d09639a..34ec003193a9 100644
--- a/pkgs/development/python-modules/aioaladdinconnect/default.nix
+++ b/pkgs/development/python-modules/aioaladdinconnect/default.nix
@@ -7,7 +7,7 @@
buildPythonPackage rec {
pname = "aioaladdinconnect";
- version = "0.1.25";
+ version = "0.1.34";
format = "setuptools";
disabled = pythonOlder "3.7";
@@ -15,7 +15,7 @@ buildPythonPackage rec {
src = fetchPypi {
pname = "AIOAladdinConnect";
inherit version;
- hash = "sha256-ruuiRhPPqsZxJgaKVtwQK8Zf7gG9r2NYnrBCosTtL/M=";
+ hash = "sha256-p5O4tm+m0ThJS/VTqhMNs2bwA2S6kJ2reQ2BoTHmLz8=";
};
propagatedBuildInputs = [
diff --git a/pkgs/development/python-modules/avro/default.nix b/pkgs/development/python-modules/avro/default.nix
index d69f009aaf4c..fd24227e03cd 100644
--- a/pkgs/development/python-modules/avro/default.nix
+++ b/pkgs/development/python-modules/avro/default.nix
@@ -8,14 +8,14 @@
buildPythonPackage rec {
pname = "avro";
- version = "1.11.0";
+ version = "1.11.1";
format = "setuptools";
disabled = pythonOlder "3.6";
src = fetchPypi {
inherit pname version;
- sha256 = "1206365cc30ad561493f735329857dd078533459cee4e928aec2505f341ce445";
+ sha256 = "sha256-8SNiPsxkjQ4gzhT47YUWIUDBPMSxCIZdGyUp+/oGwAg=";
};
propagatedBuildInputs = lib.optionals (pythonOlder "3.8") [
diff --git a/pkgs/development/python-modules/drf-yasg/default.nix b/pkgs/development/python-modules/drf-yasg/default.nix
index 28520e814cb6..9606bbcf0726 100644
--- a/pkgs/development/python-modules/drf-yasg/default.nix
+++ b/pkgs/development/python-modules/drf-yasg/default.nix
@@ -14,11 +14,11 @@
buildPythonPackage rec {
pname = "drf-yasg";
- version = "1.21.0";
+ version = "1.21.3";
src = fetchPypi {
inherit pname version;
- sha256 = "sha256-Lyh3plukEn1+7t+pp3oJbbLjdDvRIddFACmXtBfA2Go=";
+ sha256 = "sha256-su67Q4+mQVA6CNrHkb4kGD6ibbz+NxqYJOqR9uOpiKo=";
};
postPatch = ''
diff --git a/pkgs/development/python-modules/geoalchemy2/default.nix b/pkgs/development/python-modules/geoalchemy2/default.nix
index dc2b3dbd4de1..db1996a90871 100644
--- a/pkgs/development/python-modules/geoalchemy2/default.nix
+++ b/pkgs/development/python-modules/geoalchemy2/default.nix
@@ -12,12 +12,12 @@
buildPythonPackage rec {
pname = "GeoAlchemy2";
- version = "0.12.1";
+ version = "0.12.3";
format = "setuptools";
src = fetchPypi {
inherit pname version;
- sha256 = "sha256-7566ebZ/9LxyCw4ZkUEIZvx9sBODewVaGyy2UYuZTYA=";
+ sha256 = "sha256-MSgMZF3EoPkMHSmdL1x9WrZ8eENTW0ULTCq4ifAB4EI=";
};
nativeBuildInputs = [
diff --git a/pkgs/development/python-modules/logilab/constraint.nix b/pkgs/development/python-modules/logilab/constraint.nix
index bbc65a51c3c3..ca9e5b17be85 100644
--- a/pkgs/development/python-modules/logilab/constraint.nix
+++ b/pkgs/development/python-modules/logilab/constraint.nix
@@ -2,11 +2,11 @@
buildPythonPackage rec {
pname = "logilab-constraint";
- version = "0.6.0";
+ version = "0.6.2";
src = fetchPypi {
inherit pname version;
- sha256 = "1n0xim4ij1n4yvyqqvyc0wllhjs22szglsd5av0j8k2qmck4njcg";
+ sha256 = "sha256-Jk6wvvcDEeHfy7dUcjbnzFIeGBYm5tXzCI26yy+t2qs=";
};
propagatedBuildInputs = [
diff --git a/pkgs/development/python-modules/mailsuite/default.nix b/pkgs/development/python-modules/mailsuite/default.nix
index adc6ec35051d..2cb6555109cd 100644
--- a/pkgs/development/python-modules/mailsuite/default.nix
+++ b/pkgs/development/python-modules/mailsuite/default.nix
@@ -15,14 +15,14 @@
buildPythonPackage rec {
pname = "mailsuite";
- version = "1.9.2";
+ version = "1.9.4";
format = "pyproject";
disabled = pythonOlder "3.6";
src = fetchPypi {
inherit pname version;
- hash = "sha256-UV9cdWdUnUt4j1Puf1H0UxXsCHi3t4uNiKHwYNfTfa4=";
+ hash = "sha256-wgutyXxo1z3GxO3xikRlA4Og+oz+7+PrY2Hs6gicO/o=";
};
nativeBuildInputs = [
diff --git a/pkgs/development/python-modules/peaqevcore/default.nix b/pkgs/development/python-modules/peaqevcore/default.nix
index 970c1adf5b4f..a2473ead5c30 100644
--- a/pkgs/development/python-modules/peaqevcore/default.nix
+++ b/pkgs/development/python-modules/peaqevcore/default.nix
@@ -6,14 +6,14 @@
buildPythonPackage rec {
pname = "peaqevcore";
- version = "4.0.0";
+ version = "4.0.1";
format = "setuptools";
disabled = pythonOlder "3.7";
src = fetchPypi {
inherit pname version;
- hash = "sha256-q1qxjrdDLTOprgunsq70oPFgSxSZ1jOfUY6qPud/d9o=";
+ hash = "sha256-iCHXiGKg3ENqw4cX1iNpVZAA944siKbFGKooo+KswsY=";
};
postPatch = ''
diff --git a/pkgs/development/python-modules/trectools/default.nix b/pkgs/development/python-modules/trectools/default.nix
new file mode 100644
index 000000000000..1c3b2a542bc3
--- /dev/null
+++ b/pkgs/development/python-modules/trectools/default.nix
@@ -0,0 +1,59 @@
+{ lib
+, buildPythonPackage
+, fetchFromGitHub
+, beautifulsoup4
+, pythonOlder
+, pandas
+, python
+, numpy
+, scikit-learn
+, scipy
+, lxml
+, matplotlib
+, sarge
+}:
+
+buildPythonPackage rec {
+ pname = "trectools";
+ version = "0.0.49";
+
+ disabled = pythonOlder "3.6";
+
+ src = fetchFromGitHub {
+ owner = "joaopalotti";
+ repo = pname;
+ # https://github.com/joaopalotti/trectools/issues/41
+ rev = "5c1d56e9cf955f45b5a1780ee6a82744d31e7a79";
+ sha256 = "sha256-Lh6sK2rxEdCsOUKHn1jgm+rsn8FK1f2po0UuZfZajBA=";
+ };
+
+ postPatch = ''
+ substituteInPlace setup.py \
+ --replace "bs4 >= 0.0.0.1" "beautifulsoup4 >= 4.11.1"
+ '';
+
+ propagatedBuildInputs = [
+ pandas
+ numpy
+ scikit-learn
+ scipy
+ lxml
+ beautifulsoup4
+ matplotlib
+ sarge
+ ];
+
+ checkPhase = ''
+ cd unittests
+ ${python.interpreter} -m unittest runner
+ '';
+
+ pythonImportsCheck = [ "trectools" ];
+
+ meta = with lib; {
+ homepage = "https://github.com/joaopalotti/trectools";
+ description = "Library for assisting Information Retrieval (IR) practitioners with TREC-like campaigns";
+ license = licenses.bsdOriginal;
+ maintainers = with maintainers; [ MoritzBoehme ];
+ };
+}
diff --git a/pkgs/misc/drivers/xow/default.nix b/pkgs/misc/drivers/xow/default.nix
deleted file mode 100644
index c084b45d151c..000000000000
--- a/pkgs/misc/drivers/xow/default.nix
+++ /dev/null
@@ -1,45 +0,0 @@
-{ lib, stdenv, cabextract, fetchurl, fetchFromGitHub, libusb1 }:
-
-stdenv.mkDerivation rec {
- pname = "xow";
- version = "unstable-2022-04-24";
-
- src = fetchFromGitHub {
- owner = "medusalix";
- repo = "xow";
- rev = "d335d6024f8380f52767a7de67727d9b2f867871";
- sha256 = "0q5nr21p4dlx2a99hiivwz6qj9anrqqsdhiz6xi375yqkxis4251";
- };
-
- firmware = fetchurl {
- url = "http://download.windowsupdate.com/c/msdownload/update/driver/drvs/2017/07/1cd6a87c-623f-4407-a52d-c31be49e925c_e19f60808bdcbfbd3c3df6be3e71ffc52e43261e.cab";
- sha256 = "013g1zngxffavqrk5jy934q3bdhsv6z05ilfixdn8dj0zy26lwv5";
- };
-
- makeFlags = [
- "BUILD=RELEASE"
- "VERSION=${version}-${src.rev}"
- "BINDIR=${placeholder "out"}/bin"
- "UDEVDIR=${placeholder "out"}/lib/udev/rules.d"
- "MODLDIR=${placeholder "out"}/lib/modules-load.d"
- "MODPDIR=${placeholder "out"}/lib/modprobe.d"
- "SYSDDIR=${placeholder "out"}/lib/systemd/system"
- ];
-
- postUnpack = ''
- cabextract -F FW_ACC_00U.bin ${firmware}
- mv FW_ACC_00U.bin source/firmware.bin
- '';
-
- enableParallelBuilding = true;
- nativeBuildInputs = [ cabextract ];
- buildInputs = [ libusb1 ];
-
- meta = with lib; {
- homepage = "https://github.com/medusalix/xow";
- description = "Linux driver for the Xbox One wireless dongle";
- license = licenses.gpl2Plus;
- maintainers = [ maintainers.jansol ];
- platforms = platforms.linux;
- };
-}
diff --git a/pkgs/os-specific/linux/firmware/fwupd/add-option-for-installation-sysconfdir.patch b/pkgs/os-specific/linux/firmware/fwupd/add-option-for-installation-sysconfdir.patch
index 8f3a2381dc01..c136f935e03e 100644
--- a/pkgs/os-specific/linux/firmware/fwupd/add-option-for-installation-sysconfdir.patch
+++ b/pkgs/os-specific/linux/firmware/fwupd/add-option-for-installation-sysconfdir.patch
@@ -1,33 +1,33 @@
diff --git a/data/meson.build b/data/meson.build
-index 9176aa34..1a0298a9 100644
+index d8494020d..7c896fa0d 100644
--- a/data/meson.build
+++ b/data/meson.build
@@ -26,7 +26,7 @@ endif
if build_standalone
install_data(['daemon.conf'],
-- install_dir : join_paths(sysconfdir, 'fwupd')
-+ install_dir : join_paths(sysconfdir_install, 'fwupd')
+- install_dir: join_paths(sysconfdir, 'fwupd')
++ install_dir: join_paths(sysconfdir_install, 'fwupd')
)
- install_data(['power.quirk', 'cfi.quirk'],
- install_dir: join_paths(datadir, 'fwupd', 'quirks.d'))
+ plugin_quirks += join_paths(meson.current_source_dir(), 'power.quirk')
+ plugin_quirks += join_paths(meson.current_source_dir(), 'cfi.quirk')
diff --git a/data/pki/meson.build b/data/pki/meson.build
-index 499b7201..1be13607 100644
+index 3649fecea..c3462744b 100644
--- a/data/pki/meson.build
+++ b/data/pki/meson.build
@@ -12,13 +12,13 @@ install_data([
'GPG-KEY-Linux-Foundation-Firmware',
'GPG-KEY-Linux-Vendor-Firmware-Service',
],
-- install_dir : join_paths(sysconfdir, 'pki', 'fwupd')
-+ install_dir : join_paths(sysconfdir_install, 'pki', 'fwupd')
+- install_dir: join_paths(sysconfdir, 'pki', 'fwupd')
++ install_dir: join_paths(sysconfdir_install, 'pki', 'fwupd')
)
install_data([
'GPG-KEY-Linux-Foundation-Metadata',
'GPG-KEY-Linux-Vendor-Firmware-Service',
],
-- install_dir : join_paths(sysconfdir, 'pki', 'fwupd-metadata')
-+ install_dir : join_paths(sysconfdir_install, 'pki', 'fwupd-metadata')
+- install_dir: join_paths(sysconfdir, 'pki', 'fwupd-metadata')
++ install_dir: join_paths(sysconfdir_install, 'pki', 'fwupd-metadata')
)
endif
@@ -35,32 +35,32 @@ index 499b7201..1be13607 100644
install_data([
'LVFS-CA.pem',
],
-- install_dir : join_paths(sysconfdir, 'pki', 'fwupd')
-+ install_dir : join_paths(sysconfdir_install, 'pki', 'fwupd')
+- install_dir: join_paths(sysconfdir, 'pki', 'fwupd')
++ install_dir: join_paths(sysconfdir_install, 'pki', 'fwupd')
)
install_data([
'LVFS-CA.pem',
],
-- install_dir : join_paths(sysconfdir, 'pki', 'fwupd-metadata')
-+ install_dir : join_paths(sysconfdir_install, 'pki', 'fwupd-metadata')
+- install_dir: join_paths(sysconfdir, 'pki', 'fwupd-metadata')
++ install_dir: join_paths(sysconfdir_install, 'pki', 'fwupd-metadata')
)
endif
diff --git a/data/remotes.d/meson.build b/data/remotes.d/meson.build
-index 87e794b1..ebeeeca7 100644
+index 1d1698a7e..5469d00a6 100644
--- a/data/remotes.d/meson.build
+++ b/data/remotes.d/meson.build
@@ -2,7 +2,7 @@ if build_standalone and get_option('lvfs') != 'false'
install_data([
'lvfs-testing.conf',
],
-- install_dir : join_paths(sysconfdir, 'fwupd', 'remotes.d')
-+ install_dir : join_paths(sysconfdir_install, 'fwupd', 'remotes.d')
+- install_dir: join_paths(sysconfdir, 'fwupd', 'remotes.d')
++ install_dir: join_paths(sysconfdir_install, 'fwupd', 'remotes.d')
)
con3 = configuration_data()
if get_option('lvfs') == 'disabled'
@@ -15,7 +15,7 @@ if build_standalone and get_option('lvfs') != 'false'
- output : 'lvfs.conf',
- configuration : con3,
+ output: 'lvfs.conf',
+ configuration: con3,
install: true,
- install_dir: join_paths(sysconfdir, 'fwupd', 'remotes.d'),
+ install_dir: join_paths(sysconfdir_install, 'fwupd', 'remotes.d'),
@@ -68,22 +68,22 @@ index 87e794b1..ebeeeca7 100644
i18n.merge_file(
input: 'lvfs.metainfo.xml',
@@ -49,12 +49,12 @@ configure_file(
- output : 'vendor.conf',
- configuration : con2,
+ output: 'vendor.conf',
+ configuration: con2,
install: true,
- install_dir: join_paths(sysconfdir, 'fwupd', 'remotes.d'),
+ install_dir: join_paths(sysconfdir_install, 'fwupd', 'remotes.d'),
)
configure_file(
- input : 'vendor-directory.conf',
- output : 'vendor-directory.conf',
- configuration : con2,
+ input: 'vendor-directory.conf',
+ output: 'vendor-directory.conf',
+ configuration: con2,
install: true,
- install_dir: join_paths(sysconfdir, 'fwupd', 'remotes.d'),
+ install_dir: join_paths(sysconfdir_install, 'fwupd', 'remotes.d'),
)
diff --git a/meson.build b/meson.build
-index b91dd037..a8de7810 100644
+index e6b717078..f8a7a7455 100644
--- a/meson.build
+++ b/meson.build
@@ -195,6 +195,12 @@ endif
@@ -97,10 +97,10 @@ index b91dd037..a8de7810 100644
+endif
+
diffcmd = find_program('diff')
- gio = dependency('gio-2.0', version : '>= 2.45.8')
- giounix = dependency('gio-unix-2.0', version : '>= 2.45.8', required: false)
+ gio = dependency('gio-2.0', version: '>= 2.45.8')
+ giounix = dependency('gio-unix-2.0', version: '>= 2.45.8', required: false)
diff --git a/meson_options.txt b/meson_options.txt
-index d00038db..c84652ca 100644
+index 06d242371..d9e517fc0 100644
--- a/meson_options.txt
+++ b/meson_options.txt
@@ -1,3 +1,4 @@
@@ -109,75 +109,75 @@ index d00038db..c84652ca 100644
option('consolekit', type : 'feature', description : 'ConsoleKit support', deprecated: {'true': 'enabled', 'false': 'disabled'})
option('static_analysis', type : 'boolean', value : false, description : 'enable GCC static analysis support')
diff --git a/plugins/dell-esrt/meson.build b/plugins/dell-esrt/meson.build
-index 00b7ecda..789f34ca 100644
+index 67bd3b9d9..ad04a91b6 100644
--- a/plugins/dell-esrt/meson.build
+++ b/plugins/dell-esrt/meson.build
@@ -38,6 +38,6 @@ configure_file(
- output : 'dell-esrt.conf',
- configuration : con2,
+ output: 'dell-esrt.conf',
+ configuration: con2,
install: true,
- install_dir: join_paths(sysconfdir, 'fwupd', 'remotes.d'),
+ install_dir: join_paths(sysconfdir_install, 'fwupd', 'remotes.d'),
)
endif
diff --git a/plugins/msr/meson.build b/plugins/msr/meson.build
-index 1a278375..f57ae530 100644
+index 13f03ccd4..9235ebe33 100644
--- a/plugins/msr/meson.build
+++ b/plugins/msr/meson.build
-@@ -12,7 +12,7 @@ install_data(['fwupd-msr.conf'],
+@@ -10,7 +10,7 @@ install_data(['fwupd-msr.conf'],
endif
install_data(['msr.conf'],
-- install_dir: join_paths(sysconfdir, 'fwupd')
-+ install_dir: join_paths(sysconfdir_install, 'fwupd')
+- install_dir: join_paths(sysconfdir, 'fwupd')
++ install_dir: join_paths(sysconfdir_install, 'fwupd')
)
shared_module('fu_plugin_msr',
fu_hash,
diff --git a/plugins/redfish/meson.build b/plugins/redfish/meson.build
-index 8717d50f..9a703723 100644
+index 95606e478..e5355e520 100644
--- a/plugins/redfish/meson.build
+++ b/plugins/redfish/meson.build
-@@ -51,7 +51,7 @@ shared_module('fu_plugin_redfish',
+@@ -43,7 +43,7 @@ shared_module('fu_plugin_redfish',
)
install_data(['redfish.conf'],
-- install_dir: join_paths(sysconfdir, 'fwupd'),
-+ install_dir: join_paths(sysconfdir_install, 'fwupd'),
+- install_dir: join_paths(sysconfdir, 'fwupd'),
++ install_dir: join_paths(sysconfdir_install, 'fwupd'),
)
if get_option('tests')
diff --git a/plugins/thunderbolt/meson.build b/plugins/thunderbolt/meson.build
-index aa6c8ce1..61734c4d 100644
+index 5f8ffbf90..9ba323e75 100644
--- a/plugins/thunderbolt/meson.build
+++ b/plugins/thunderbolt/meson.build
-@@ -35,7 +35,7 @@ fu_plugin_thunderbolt = shared_module('fu_plugin_thunderbolt',
+@@ -32,7 +32,7 @@ fu_plugin_thunderbolt = shared_module('fu_plugin_thunderbolt',
)
install_data(['thunderbolt.conf'],
-- install_dir: join_paths(sysconfdir, 'fwupd')
-+ install_dir: join_paths(sysconfdir_install, 'fwupd')
+- install_dir: join_paths(sysconfdir, 'fwupd')
++ install_dir: join_paths(sysconfdir_install, 'fwupd')
)
# we use functions from 2.52 in the tests
if get_option('tests') and run_sanitize_unsafe_tests and umockdev.found() and gio.version().version_compare('>= 2.52')
diff --git a/plugins/uefi-capsule/meson.build b/plugins/uefi-capsule/meson.build
-index 2d9ba819..0feb5f6b 100644
+index ef38dc03e..78ff65e1d 100644
--- a/plugins/uefi-capsule/meson.build
+++ b/plugins/uefi-capsule/meson.build
-@@ -21,7 +21,7 @@ if host_machine.system() == 'linux'
- output : '35_fwupd',
- configuration : con2,
+@@ -20,7 +20,7 @@ if host_machine.system() == 'linux'
+ output: '35_fwupd',
+ configuration: con2,
install: true,
- install_dir: join_paths(sysconfdir, 'grub.d')
+ install_dir: join_paths(sysconfdir_install, 'grub.d')
)
elif host_machine.system() == 'freebsd'
backend_srcs += 'fu-uefi-backend-freebsd.c'
-@@ -112,7 +112,7 @@ if get_option('compat_cli') and get_option('man')
+@@ -110,7 +110,7 @@ if get_option('compat_cli') and get_option('man')
endif
install_data(['uefi_capsule.conf'],
-- install_dir: join_paths(sysconfdir, 'fwupd')
-+ install_dir: join_paths(sysconfdir_install, 'fwupd')
+- install_dir: join_paths(sysconfdir, 'fwupd')
++ install_dir: join_paths(sysconfdir_install, 'fwupd')
)
# add all the .po files as inputs to watch
diff --git a/pkgs/os-specific/linux/firmware/fwupd/default.nix b/pkgs/os-specific/linux/firmware/fwupd/default.nix
index 94a5c2ac0366..ce6dc1a1b27c 100644
--- a/pkgs/os-specific/linux/firmware/fwupd/default.nix
+++ b/pkgs/os-specific/linux/firmware/fwupd/default.nix
@@ -4,7 +4,7 @@
, lib
, fetchurl
, fetchFromGitHub
-, gtk-doc
+, gi-docgen
, pkg-config
, gobject-introspection
, gettext
@@ -17,7 +17,6 @@
, libarchive
, curl
, libjcat
-, libxslt
, elfutils
, libsmbios
, efivar
@@ -25,8 +24,6 @@
, meson
, libuuid
, colord
-, docbook_xml_dtd_43
-, docbook-xsl-nons
, ninja
, gcab
, gnutls
@@ -117,7 +114,7 @@ let
self = stdenv.mkDerivation rec {
pname = "fwupd";
- version = "1.8.1";
+ version = "1.8.3";
# libfwupd goes to lib
# daemon, plug-ins and libfwupdplugin go to out
@@ -126,7 +123,7 @@ let
src = fetchurl {
url = "https://people.freedesktop.org/~hughsient/releases/fwupd-${version}.tar.xz";
- sha256 = "sha256-V1ZGZELrkTT7QM3IpG+eAQAyR8jqyC+l2LFvZCA3W3k=";
+ sha256 = "sha256-ciIpd86KhmJRH/o8CIFWb2xFjsjWHSUNlGYRfWEiOOw=";
};
patches = [
@@ -152,7 +149,7 @@ let
nativeBuildInputs = [
meson
ninja
- gtk-doc
+ gi-docgen
pkg-config
gobject-introspection
gettext
@@ -160,9 +157,6 @@ let
valgrind
gcab
gnutls
- docbook_xml_dtd_43
- docbook-xsl-nons
- libxslt
protobufc # for protoc
python
wrapGAppsHook
@@ -201,7 +195,7 @@ let
];
mesonFlags = [
- "-Ddocs=gtkdoc"
+ "-Ddocs=enabled"
"-Dplugin_dummy=true"
# We are building the official releases.
"-Dsupported_build=enabled"
@@ -216,6 +210,8 @@ let
"-Dsysconfdir_install=${placeholder "out"}/etc"
"-Defi_os_dir=nixos"
"-Dplugin_modem_manager=enabled"
+ # Requires Meson 0.63
+ "-Dgresource_quirks=disabled"
# We do not want to place the daemon into lib (cyclic reference)
"--libexecdir=${placeholder "out"}/libexec"
@@ -261,10 +257,20 @@ let
meson_post_install.sh \
po/test-deps
+ # This checks a version of a dependency of gi-docgen but gi-docgen is self-contained in Nixpkgs.
+ echo "Clearing docs/test-deps.py"
+ test -f docs/test-deps.py
+ echo > docs/test-deps.py
+
substituteInPlace data/installed-tests/fwupdmgr-p2p.sh \
--replace "gdbus" ${glib.bin}/bin/gdbus
'';
+ preBuild = ''
+ # jcat-tool at buildtime requires a home directory
+ export HOME="$(mktemp -d)"
+ '';
+
preCheck = ''
addToSearchPath XDG_DATA_DIRS "${shared-mime-info}/share"
'';
@@ -298,8 +304,8 @@ let
)
'';
- # Since we had to disable wrapGAppsHook, we need to wrap the executables manually.
postFixup = ''
+ # Since we had to disable wrapGAppsHook, we need to wrap the executables manually.
find -L "$out/bin" "$out/libexec" -type f -executable -print0 \
| while IFS= read -r -d ''' file; do
if [[ "$file" != *.efi ]]; then
@@ -307,6 +313,9 @@ let
wrapGApp "$file"
fi
done
+
+ # Cannot be in postInstall, otherwise _multioutDocs hook in preFixup will move right back.
+ moveToOutput "share/doc" "$devdoc"
'';
separateDebugInfo = true;
diff --git a/pkgs/os-specific/linux/firmware/fwupd/install-fwupdplugin-to-out.patch b/pkgs/os-specific/linux/firmware/fwupd/install-fwupdplugin-to-out.patch
index c67665f21207..f3369b6e1333 100644
--- a/pkgs/os-specific/linux/firmware/fwupd/install-fwupdplugin-to-out.patch
+++ b/pkgs/os-specific/linux/firmware/fwupd/install-fwupdplugin-to-out.patch
@@ -4,11 +4,11 @@ index 1afa28e1..3da81d30 100644
+++ b/libfwupdplugin/meson.build
@@ -220,7 +220,8 @@ fwupdplugin = library(
],
- link_args : cc.get_supported_link_arguments([vflag]),
- link_depends : fwupdplugin_mapfile,
-- install : true
-+ install : true,
-+ install_dir : bindir / '..' / 'lib',
+ link_args: cc.get_supported_link_arguments([vflag]),
+ link_depends: fwupdplugin_mapfile,
+- install: true
++ install: true,
++ install_dir: bindir / '..' / 'lib',
)
fwupdplugin_pkgg = import('pkgconfig')
@@ -16,9 +16,9 @@ index 1afa28e1..3da81d30 100644
girtargets,
fwupd_gir[0],
],
-- install : true
-+ install : true,
-+ install_dir_typelib : bindir / '..' / 'lib' / 'girepository-1.0',
+- install: true
++ install: true,
++ install_dir_typelib: bindir / '..' / 'lib' / 'girepository-1.0',
)
# Verify the map file is correct -- note we can't actually use the generated
diff --git a/pkgs/servers/endlessh-go/default.nix b/pkgs/servers/endlessh-go/default.nix
index 320d5c4137c0..ffd8c355b841 100644
--- a/pkgs/servers/endlessh-go/default.nix
+++ b/pkgs/servers/endlessh-go/default.nix
@@ -5,18 +5,16 @@
buildGoModule rec {
pname = "endlessh-go";
- version = "20220710";
+ version = "20220731";
src = fetchFromGitHub {
owner = "shizunge";
repo = "endlessh-go";
rev = version;
- sha256 = "sha256-T8DLzHfITMLeHJtKuK4AjEzGGCIDJUPlqF2Lj56xPxY=";
+ sha256 = "sha256-xV9VCbpd6JC/m3RXJt0v8WCCGs8UpZLvAv3bzPRrae4=";
};
- vendorSha256 = "sha256-hMCjYAqsI6h9B8iGVYQcNbKU5icalOHavvPKwOmvf/w=";
-
- proxyVendor = true;
+ vendorSha256 = "sha256-YGVLntDnOX55IoIHIn0z1K7V/PhRLruEASfAGQsTUkk=";
ldflags = [ "-s" "-w" ];
diff --git a/pkgs/servers/klipper/klipper-firmware.nix b/pkgs/servers/klipper/klipper-firmware.nix
new file mode 100644
index 000000000000..f80cec0b687e
--- /dev/null
+++ b/pkgs/servers/klipper/klipper-firmware.nix
@@ -0,0 +1,61 @@
+{ stdenv
+, lib
+, pkg-config
+, pkgsCross
+, bintools-unwrapped
+, libffi
+, libusb1
+, wxGTK
+, python2
+, python3
+, gcc-arm-embedded
+, klipper
+, avrdude
+, stm32flash
+, mcu ? "mcu"
+, firmwareConfig ? ./simulator.cfg
+}: stdenv.mkDerivation rec {
+ name = "klipper-firmware-${mcu}-${version}";
+ version = klipper.version;
+ src = klipper.src;
+
+ nativeBuildInputs = [
+ python2
+ python3
+ pkgsCross.avr.stdenv.cc
+ gcc-arm-embedded
+ bintools-unwrapped
+ libffi
+ libusb1
+ avrdude
+ stm32flash
+ pkg-config
+ wxGTK # Required for bossac
+ ];
+
+ preBuild = "cp ${firmwareConfig} ./.config";
+
+ postPatch = ''
+ patchShebangs .
+ '';
+
+ makeFlags = [
+ "V=1"
+ "KCONFIG_CONFIG=${firmwareConfig}"
+ ];
+
+ installPhase = ''
+ mkdir -p $out
+ cp ./.config $out/config
+ cp -r out/* $out
+ '';
+
+ dontFixup = true;
+
+ meta = with lib; {
+ inherit (klipper.meta) homepage license;
+ description = "Firmware part of Klipper";
+ maintainers = with maintainers; [ vtuan10 ];
+ platforms = platforms.linux;
+ };
+}
diff --git a/pkgs/servers/klipper/klipper-flash.nix b/pkgs/servers/klipper/klipper-flash.nix
new file mode 100644
index 000000000000..fedc477c2761
--- /dev/null
+++ b/pkgs/servers/klipper/klipper-flash.nix
@@ -0,0 +1,38 @@
+{ lib
+, writeShellApplication
+, gnumake
+, pkgsCross
+, klipper
+, klipper-firmware
+, python2
+, avrdude
+, stm32flash
+, mcu ? "mcu"
+, flashDevice ? "/dev/null"
+, firmwareConfig ? ./simulator.cfg
+}:
+let
+ supportedArches = [ "avr" "stm32" "lpc176x" ];
+ matchBoard = with builtins; match ''^.*CONFIG_BOARD_DIRECTORY="([a-zA-Z0-9_]+)".*$'' (readFile firmwareConfig);
+ boardArch = if matchBoard == null then null else builtins.head matchBoard;
+in
+writeShellApplication {
+ name = "klipper-flash-${mcu}";
+ runtimeInputs = [
+ python2
+ pkgsCross.avr.stdenv.cc
+ gnumake
+ ] ++ lib.optionals (boardArch == "avr") [ avrdude ] ++ lib.optionals (boardArch == "stm32") [ stm32flash ];
+ text = ''
+ if ${lib.boolToString (!builtins.elem boardArch supportedArches)}; then
+ printf "Flashing Klipper firmware to your board is not supported yet.\n"
+ printf "Please use the compiled firmware at ${klipper-firmware} and flash it using the tools provided for your microcontroller."
+ exit 1
+ fi
+ if ${lib.boolToString (boardArch == "stm32")}; then
+ make -C ${klipper.src} FLASH_DEVICE="${toString flashDevice}" OUT="${klipper-firmware}/" KCONFIG_CONFIG="${klipper-firmware}/config" serialflash
+ else
+ make -C ${klipper.src} FLASH_DEVICE="${toString flashDevice}" OUT="${klipper-firmware}/" KCONFIG_CONFIG="${klipper-firmware}/config" flash
+ fi
+ '';
+}
diff --git a/pkgs/servers/klipper/klipper-genconf.nix b/pkgs/servers/klipper/klipper-genconf.nix
new file mode 100644
index 000000000000..42eb519e8c19
--- /dev/null
+++ b/pkgs/servers/klipper/klipper-genconf.nix
@@ -0,0 +1,21 @@
+{ writeShellApplication
+, klipper
+, python2
+, gnumake
+, pkgsCross
+}: writeShellApplication {
+ name = "klipper-genconf";
+ runtimeInputs = [
+ python2
+ pkgsCross.avr.stdenv.cc
+ gnumake
+ ];
+ text = ''
+ CURRENT_DIR=$(pwd)
+ TMP=$(mktemp -d)
+ make -C ${klipper.src} OUT="$TMP" KCONFIG_CONFIG="$CURRENT_DIR/config" menuconfig
+ rm -rf "$TMP" config.old
+ printf "\nYour firmware configuration for klipper:\n\n"
+ cat config
+ '';
+}
diff --git a/pkgs/servers/klipper/simulator.cfg b/pkgs/servers/klipper/simulator.cfg
new file mode 100644
index 000000000000..4dc19b1e40ff
--- /dev/null
+++ b/pkgs/servers/klipper/simulator.cfg
@@ -0,0 +1,23 @@
+# CONFIG_LOW_LEVEL_OPTIONS is not set
+# CONFIG_MACH_AVR is not set
+# CONFIG_MACH_ATSAM is not set
+# CONFIG_MACH_ATSAMD is not set
+# CONFIG_MACH_LPC176X is not set
+# CONFIG_MACH_STM32 is not set
+# CONFIG_MACH_RP2040 is not set
+# CONFIG_MACH_PRU is not set
+# CONFIG_MACH_LINUX is not set
+CONFIG_MACH_SIMU=y
+CONFIG_BOARD_DIRECTORY="simulator"
+CONFIG_CLOCK_FREQ=20000000
+CONFIG_SERIAL=y
+CONFIG_SIMULATOR_SELECT=y
+CONFIG_SERIAL_BAUD=250000
+CONFIG_USB_VENDOR_ID=0x1d50
+CONFIG_USB_DEVICE_ID=0x614e
+CONFIG_USB_SERIAL_NUMBER="12345"
+CONFIG_HAVE_GPIO=y
+CONFIG_HAVE_GPIO_ADC=y
+CONFIG_HAVE_GPIO_SPI=y
+CONFIG_HAVE_GPIO_HARD_PWM=y
+CONFIG_INLINE_STEPPER_HACK=y
diff --git a/pkgs/servers/monitoring/net-snmp/default.nix b/pkgs/servers/monitoring/net-snmp/default.nix
index 5e7aa35d6228..e4447d7a844c 100644
--- a/pkgs/servers/monitoring/net-snmp/default.nix
+++ b/pkgs/servers/monitoring/net-snmp/default.nix
@@ -10,11 +10,11 @@
in stdenv.mkDerivation rec {
pname = "net-snmp";
- version = "5.9.1";
+ version = "5.9.3";
src = fetchurl {
url = "mirror://sourceforge/net-snmp/${pname}-${version}.tar.gz";
- sha256 = "sha256-63/UpE3mzdv/2akqha0TCeXBBU+51afdkweciVP0jD8=";
+ sha256 = "sha256-IJfym34b8/EwC0uuUvojCNC7jV05mNvgL5RipBOi7wo=";
};
patches =
diff --git a/pkgs/tools/admin/copilot-cli/default.nix b/pkgs/tools/admin/copilot-cli/default.nix
new file mode 100644
index 000000000000..3e12116d6e2a
--- /dev/null
+++ b/pkgs/tools/admin/copilot-cli/default.nix
@@ -0,0 +1,47 @@
+{ lib, buildGoModule, fetchFromGitHub, installShellFiles, testers, copilot-cli }:
+
+buildGoModule rec {
+ pname = "copilot-cli";
+ version = "1.19.0";
+
+ src = fetchFromGitHub {
+ owner = "aws";
+ repo = pname;
+ rev = "v${version}";
+ sha256 = "sha256-2zF/cBc6TjAcFAI3zJ0yBQrVWDK5nkxYYkb04bjSjgY=";
+ };
+
+ vendorSha256 = "sha256-1UFahXol1Lceccr/f24Mbhtk8bWyh4+Mb5VYZvF6VWs=";
+
+ nativeBuildInputs = [ installShellFiles ];
+
+ # follow LINKER_FLAGS in Makefile
+ ldflags = [
+ "-s"
+ "-w"
+ "-X github.com/aws/copilot-cli/internal/pkg/version.Version=${version}"
+ "-X github.com/aws/copilot-cli/internal/pkg/cli.binaryS3BucketPath=https://ecs-cli-v2-release.s3.amazonaws.com"
+ ];
+
+ subPackages = [ "./cmd/copilot" ];
+
+ postInstall = ''
+ installShellCompletion --cmd copilot \
+ --bash <($out/bin/copilot completion bash) \
+ --fish <($out/bin/copilot completion fish) \
+ --zsh <($out/bin/copilot completion zsh)
+ '';
+
+ passthru.tests.version = testers.testVersion {
+ package = copilot-cli;
+ command = "copilot version";
+ };
+
+ meta = with lib; {
+ description = "Build, Release and Operate Containerized Applications on AWS.";
+ homepage = "https://github.com/aws/copilot-cli";
+ changelog = "https://github.com/aws/copilot-cli/releases/tag/v${version}";
+ license = licenses.asl20;
+ maintainers = with maintainers; [ jiegec ];
+ };
+}
diff --git a/pkgs/tools/admin/wander/default.nix b/pkgs/tools/admin/wander/default.nix
index 628377d7f644..f215deacac99 100644
--- a/pkgs/tools/admin/wander/default.nix
+++ b/pkgs/tools/admin/wander/default.nix
@@ -2,16 +2,16 @@
buildGoModule rec {
pname = "wander";
- version = "0.5.1";
+ version = "0.7.0";
src = fetchFromGitHub {
owner = "robinovitch61";
repo = pname;
rev = "v${version}";
- sha256 = "sha256-B+mMC5XGUTNTcxwKhvSSc7QbsLkg8qu7/jJf5U/q6s8=";
+ sha256 = "sha256-aQqJDUDYHoUZ6ixnY3lmFOx29QpRRke5XHFIpsA+Bnw=";
};
- vendorSha256 = "sha256-gWQ8GbtghhCRq6tOU6qmWBuponmfUkUDAk3+dPtmMiE=";
+ vendorSha256 = "sha256-T+URnRLumXFz48go9TN0Wha99T03OWGfDK7cQ+zKeRI=";
meta = with lib; {
description = "Terminal app/TUI for HashiCorp Nomad";
diff --git a/pkgs/tools/audio/volumeicon/default.nix b/pkgs/tools/audio/volumeicon/default.nix
index 4d726cbd2a9e..00690d016329 100644
--- a/pkgs/tools/audio/volumeicon/default.nix
+++ b/pkgs/tools/audio/volumeicon/default.nix
@@ -1,24 +1,36 @@
-{ pkgs, fetchurl, lib, stdenv, gtk3, pkg-config, intltool, alsa-lib }:
+{ fetchFromGitHub, lib, stdenv
+, autoreconfHook, intltool, pkg-config
+, gtk3, alsa-lib
+}:
-stdenv.mkDerivation {
+stdenv.mkDerivation rec {
pname = "volumeicon";
version = "0.5.1";
- src = fetchurl {
- url = "http://softwarebakery.com/maato/files/volumeicon/volumeicon-0.5.1.tar.gz";
- sha256 = "182xl2w8syv6ky2h2bc9imc6ap8pzh0p7rp63hh8nw0xm38c3f14";
+ src = fetchFromGitHub {
+ owner = "Maato";
+ repo = "volumeicon";
+ rev = version;
+ hash = "sha256-zYKC7rOoLf08rV4B43TrGNBcXfSBFxWZCe9bQD9JzaA";
};
- nativeBuildInputs = [ pkg-config ];
- buildInputs = [ gtk3 intltool alsa-lib ];
+ nativeBuildInputs = [
+ autoreconfHook
+ intltool
+ pkg-config
+ ];
+
+ buildInputs = [
+ gtk3
+ alsa-lib
+ ];
meta = with lib; {
description = "A lightweight volume control that sits in your systray";
- homepage = "http://softwarebakery.com/maato/volumeicon.html";
- platforms = pkgs.lib.platforms.linux;
+ homepage = "http://nullwise.com/volumeicon.html";
+ platforms = platforms.linux;
maintainers = with maintainers; [ bobvanderlinden ];
- license = pkgs.lib.licenses.gpl3;
+ license = licenses.gpl3;
};
-
}
diff --git a/pkgs/tools/security/httpx/default.nix b/pkgs/tools/security/httpx/default.nix
index 2519e714b70b..de7060e69f19 100644
--- a/pkgs/tools/security/httpx/default.nix
+++ b/pkgs/tools/security/httpx/default.nix
@@ -5,16 +5,16 @@
buildGoModule rec {
pname = "httpx";
- version = "1.2.3";
+ version = "1.2.4";
src = fetchFromGitHub {
owner = "projectdiscovery";
repo = "httpx";
rev = "v${version}";
- sha256 = "sha256-gBt1xllfzw8M+n+vgUmOQ3vgDxDuDaQ7YXfWdLWnpVk=";
+ sha256 = "sha256-w4VELxmahqjfiMGXflSnhp5NKPi3HUucjxEUegljbVY=";
};
- vendorSha256 = "sha256-9ZwRbeZ1iSuJiIJDBauU1U9PpGn8QQPTd3MfrnSmF+w=";
+ vendorSha256 = "sha256-9zLZyXrLvxwwkTwtpKxdGftzCZISZ/al98VnPiaMqGA=";
meta = with lib; {
description = "Fast and multi-purpose HTTP toolkit";
diff --git a/pkgs/tools/text/link-grammar/default.nix b/pkgs/tools/text/link-grammar/default.nix
index 876e9971fd29..28cd894393ee 100644
--- a/pkgs/tools/text/link-grammar/default.nix
+++ b/pkgs/tools/text/link-grammar/default.nix
@@ -14,13 +14,13 @@ let
link-grammar = stdenv.mkDerivation rec {
pname = "link-grammar";
- version = "5.10.4";
+ version = "5.10.5";
outputs = [ "bin" "out" "dev" "man" ];
src = fetchurl {
url = "http://www.abisource.com/downloads/${pname}/${version}/${pname}-${version}.tar.gz";
- sha256 = "sha256-Pd4tEsre7aGTlEoereSElisCGXXhwgZDTMt4UEZIf4E=";
+ sha256 = "sha256-MkcQzYEyl1/5zLU1CXMvdVhHOxwZ8XiSAAo97bhhiu0=";
};
nativeBuildInputs = [
diff --git a/pkgs/tools/virtualization/linode-cli/default.nix b/pkgs/tools/virtualization/linode-cli/default.nix
index 506249454331..76913951b621 100644
--- a/pkgs/tools/virtualization/linode-cli/default.nix
+++ b/pkgs/tools/virtualization/linode-cli/default.nix
@@ -11,7 +11,7 @@
}:
let
- sha256 = "1yglnmwspdncqmy5x0zc0g43bfm4597zfmwfvs7qkalv1pprf0s3";
+ sha256 = "1fv53wikx745kci86xrsq9kfsgv0a65srhywdw32cab1wywwpn2z";
# specVersion taken from: https://www.linode.com/docs/api/openapi.yaml at `info.version`.
specVersion = "4.132.0";
specSha256 = "0r0l23bvaj406xam7hglfx637cxja3g2vqdqx3x0ag7jfhg0s3k5";
@@ -24,7 +24,7 @@ in
buildPythonApplication rec {
pname = "linode-cli";
- version = "5.21.0";
+ version = "5.22.0";
src = fetchFromGitHub {
owner = "linode";
diff --git a/pkgs/top-level/aliases.nix b/pkgs/top-level/aliases.nix
index 68dd3686d985..3c28d18108c1 100644
--- a/pkgs/top-level/aliases.nix
+++ b/pkgs/top-level/aliases.nix
@@ -408,6 +408,7 @@ mapAliases ({
facette = throw "facette has been removed"; # Added 2020-01-06
fast-neural-doodle = throw "fast-neural-doodle has been removed, as the upstream project has been abandoned"; # Added 2020-03-28
fastnlo = fastnlo_toolkit; # Added 2021-04-24
+ fbreader = throw "fbreader has been removed, as the upstream project has been archived"; # Added 2022-05-26
fedora-coreos-config-transpiler = throw "fedora-coreos-config-transpiler has been renamed to 'butane'"; # Added 2021-04-13
feedreader = throw "feedreader is no longer activily maintained since 2019. The developer is working on a spiritual successor called NewsFlash."; # Added 2022-05-03
fetchFromGithub = throw "You meant fetchFromGitHub, with a capital H";
@@ -1523,6 +1524,10 @@ mapAliases ({
'';
xf86_input_multitouch = throw "xf86_input_multitouch has been removed from nixpkgs"; # Added 2020-01-20
xlibs = throw "'xlibs' has been renamed to/replaced by 'xorg'"; # Converted to throw 2022-02-22
+ xow = throw (
+ "Upstream has ended support for 'xow' and the package has been removed" +
+ "from nixpkgs. Users are urged to switch to 'xone'."
+ ); # Added 2022-08-02
xpraGtk3 = throw "'xpraGtk3' has been renamed to/replaced by 'xpra'"; # Converted to throw 2022-02-22
xv = xxv; # Added 2020-02-22
xvfb_run = xvfb-run; # Added 2021-05-07
diff --git a/pkgs/top-level/all-packages.nix b/pkgs/top-level/all-packages.nix
index bb8fffa9bddc..4af577780c87 100644
--- a/pkgs/top-level/all-packages.nix
+++ b/pkgs/top-level/all-packages.nix
@@ -386,6 +386,8 @@ with pkgs;
coordgenlibs = callPackage ../development/libraries/coordgenlibs { };
+ copilot-cli = callPackage ../tools/admin/copilot-cli { };
+
cp437 = callPackage ../tools/misc/cp437 { };
cpm = callPackage ../development/tools/cpm { };
@@ -4044,6 +4046,12 @@ with pkgs;
klipper = callPackage ../servers/klipper { };
+ klipper-firmware = callPackage ../servers/klipper/klipper-firmware.nix { };
+
+ klipper-flash = callPackage ../servers/klipper/klipper-flash.nix { };
+
+ klipper-genconf = callPackage ../servers/klipper/klipper-genconf.nix { };
+
klog = qt5.callPackage ../applications/radio/klog { };
krapslog = callPackage ../tools/misc/krapslog { };
@@ -10495,7 +10503,9 @@ with pkgs;
secp256k1 = callPackage ../tools/security/secp256k1 { };
- securefs = callPackage ../tools/filesystems/securefs { };
+ securefs = callPackage ../tools/filesystems/securefs {
+ stdenv = clangStdenv;
+ };
seehecht = callPackage ../tools/text/seehecht { };
@@ -17002,6 +17012,8 @@ with pkgs;
arb = callPackage ../development/libraries/arb {};
+ argparse = callPackage ../development/libraries/argparse { };
+
argp-standalone = callPackage ../development/libraries/argp-standalone {};
aribb25 = callPackage ../development/libraries/aribb25 {
@@ -26811,10 +26823,6 @@ with pkgs;
fbpanel = callPackage ../applications/window-managers/fbpanel { };
- fbreader = callPackage ../applications/misc/fbreader {
- inherit (darwin.apple_sdk.frameworks) AppKit Cocoa;
- };
-
fdr = libsForQt5.callPackage ../applications/science/programming/fdr { };
feedbackd = callPackage ../applications/misc/feedbackd { };
@@ -35745,8 +35753,6 @@ with pkgs;
xorex = callPackage ../tools/security/xorex { };
- xow = callPackage ../misc/drivers/xow { };
-
xbps = callPackage ../tools/package-management/xbps { };
xcftools = callPackage ../tools/graphics/xcftools { };
diff --git a/pkgs/top-level/python-packages.nix b/pkgs/top-level/python-packages.nix
index 668938b61ebe..ccdf1ba1b857 100644
--- a/pkgs/top-level/python-packages.nix
+++ b/pkgs/top-level/python-packages.nix
@@ -171,6 +171,8 @@ in {
adafruit-io = callPackage ../development/python-modules/adafruit-io { };
+ adafruit-nrfutil = callPackage ../development/python-modules/adafruit-nrfutil { };
+
adafruit-platformdetect = callPackage ../development/python-modules/adafruit-platformdetect { };
adafruit-pureio = callPackage ../development/python-modules/adafruit-pureio { };
@@ -10769,6 +10771,8 @@ in {
transmissionrpc = callPackage ../development/python-modules/transmissionrpc { };
+ trectools = callPackage ../development/python-modules/trectools { };
+
treelog = callPackage ../development/python-modules/treelog { };
treeo = callPackage ../development/python-modules/treeo { };
diff --git a/pkgs/development/go-modules/generic/default.nix b/pkgs/development/go-modules/generic/default.nix
index 4fd94cc30371..8b5185979e45 100644
--- a/pkgs/development/go-modules/generic/default.nix
+++ b/pkgs/development/go-modules/generic/default.nix
@@ -19,17 +19,20 @@
# path to go.mod and go.sum directory
, modRoot ? "./"
# vendorSha256 is the sha256 of the vendored dependencies
#
-# if vendorSha256 is null, then we won't fetch any dependencies and
+# if vendorHash is null, then we won't fetch any dependencies and
# rely on the vendor folder within the source.
-, vendorSha256
+, vendorHash ? "_unset"
+# same as vendorHash, but outputHashAlgo is hardcoded to sha256
+# so regular base32 sha256 hashes work
+, vendorSha256 ? "_unset"
# Whether to delete the vendor folder supplied with the source.
, deleteVendor ? false
# Whether to fetch (go mod download) and proxy the vendor directory.
# This is useful if your code depends on c code and go mod tidy does not
# include the needed sources to build or if any dependency has case-insensitive
# conflicts which will produce platform dependant `vendorSha256` checksums.
, proxyVendor ? false
# We want parallel builds by default
@@ -55,11 +58,23 @@
with builtins;
assert goPackagePath != "" -> throw "`goPackagePath` is not needed with `buildGoModule`";
+assert (vendorSha256 == "_unset" && vendorHash == "_unset") -> throw "either `vendorHash` or `vendorSha256` is required";
+assert (vendorSha256 != "_unset" && vendorHash != "_unset") -> throw "both `vendorHash` and `vendorSha256` set. only one can be set.";
let
- args = removeAttrs args' [ "overrideModAttrs" "vendorSha256" ];
+ hasAnyVendorHash = (vendorSha256 != null && vendorSha256 != "_unset") || (vendorHash != null && vendorHash != "_unset");
+ vendorHashType =
+ if hasAnyVendorHash then
+ if vendorSha256 != null && vendorSha256 != "_unset" then
+ "sha256"
+ else
+ "sri"
+ else
+ null;
- go-modules = if vendorSha256 != null then stdenv.mkDerivation (let modArgs = {
+ args = removeAttrs args' [ "overrideModAttrs" "vendorSha256" "vendorHash" ];
+
+ go-modules = if hasAnyVendorHash then stdenv.mkDerivation (let modArgs = {
name = "${name}-go-modules";
@@ -98,7 +113,7 @@ let
fi
'' + ''
if [ -d vendor ]; then
- echo "vendor folder exists, please set 'vendorSha256 = null;' in your expression"
+ echo "vendor folder exists, please set 'vendorHash = null;' or 'vendorSha256 = null;' in your expression"
exit 10
fi
@@ -134,9 +149,14 @@ let
}; in modArgs // (
{
outputHashMode = "recursive";
+ } // (if (vendorHashType == "sha256") then {
outputHashAlgo = "sha256";
outputHash = vendorSha256;
- }
+ } else {
+ outputHash = vendorHash;
+ }) // (lib.optionalAttrs (vendorHashType == "sri" && vendorHash == "") {
+ outputHashAlgo = "sha256";
+ })
) // overrideModAttrs modArgs) else "";
package = stdenv.mkDerivation (args // {
@@ -156,7 +176,7 @@ let
export GOPROXY=off
export GOSUMDB=off
cd "$modRoot"
- '' + lib.optionalString (vendorSha256 != null) ''
+ '' + lib.optionalString hasAnyVendorHash ''
${if proxyVendor then ''
export GOPROXY=file://${go-modules}
'' else ''
@@ -276,7 +296,7 @@ let
disallowedReferences = lib.optional (!allowGoReference) go;
- passthru = passthru // { inherit go go-modules vendorSha256 ; };
+ passthru = passthru // { inherit go go-modules vendorSha256 vendorHash; };
enableParallelBuilding = enableParallelBuilding;
@@ -19,17 +19,20 @@
# path to go.mod and go.sum directory
, modRoot ? "./"
-# vendorSha256 is the sha256 of the vendored dependencies
+# vendorHash is the SRI hash of the vendored dependencies
#
@@ -19,17 +19,20 @@
# This is useful if your code depends on c code and go mod tidy does not
# include the needed sources to build or if any dependency has case-insensitive
-# conflicts which will produce platform dependant `vendorSha256` checksums.
+# conflicts which will produce platform dependant `vendorHash` checksums.
, proxyVendor ? false
# We want parallel builds by default